# Sage - Abstract Algebra: Theory and Applications

This package was designed as part of a Project at Southern Utah University.  The original project can be found at
[Github](https://github.com/bradencarlson/sage-jupyter) and was originally written in SageMath in Jupyter Notebooks.

The original project was designed to be used in Jupyter Notebooks, but this package was later created for those who wish to 
easily use the functions in this project from a Sage Terminal.  

Please note that this package is **not** meant to be run in Python, but rather is meant to be run in a SageMath terminal.  Thus, while some of the functions defined in this project may work, for full functionality, SageMath is needed. 


